class Wallet: 
    def __init__(self, bank_notes): ...

    def withdraw(self, amount): ...
    def deposit(self, amount): ...
    def total_money(self): ...
    def check_if_exact(self, bill_combination): ...
    def propose_bill_combinations(self, amount, also_suggest_smaller_values): ...
    def can_afford(self, payment_amount): ...
    def bank_notes(self): ...



